%define shortname redhat-ds
%define pkgname   dirsrv

Summary:          Red Hat Administration Server (admin)
Name:             redhat-ds-admin
Version:          8.2.1
Release:          1%{?dist}
License:          GPLv2 and ASL 2.0
URL:              http://www.redhat.com/directory_server
Group:            System Environment/Daemons
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:    nspr-devel
BuildRequires:    nss-devel
BuildRequires:    svrcore-devel
BuildRequires:    mozldap6-devel
BuildRequires:    cyrus-sasl-devel
BuildRequires:    icu
BuildRequires:    libicu-devel
BuildRequires:    httpd-devel
BuildRequires:    apr-devel
BuildRequires:    fortitude-mod_nss
BuildRequires:    adminutil-devel >= 1.1.8

Requires:         redhat-ds-base
Requires:         fortitude-mod_nss
# the following are needed for some of our scripts
Requires:         perl-Mozilla-LDAP
Requires:         nss-tools

# for the init script
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service

Source0:          %{name}-%{version}.tar.bz2
# redhat-ds-cvs.sh should be used to generate the source tarball from CVS
Source1:          %{name}-cvs.sh

%description
Red Hat Administration Server is an HTTP agent that provides management features
for Red Hat Directory Server.  It provides some management web apps that can
be used through a web browser.  It provides the authentication, access control,
and CGI utilities used by the console.

%prep
%setup -q -n %{name}-%{version}

%build
%configure --disable-rpath --with-fortitude

# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64 ppc64 ia64 s390x sparc64
export USE_64=1
%endif

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT 

make DESTDIR="$RPM_BUILD_ROOT" install

# make console jars directory
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{pkgname}/html/java

#remove libtool and static libs
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.so
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/modules/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/modules/*.la

%clean
rm -rf $RPM_BUILD_ROOT

%pre
# save permission info in temp file
# if upgrading
if [ "$1" -gt 1 ] ; then
    set -x
    mydt=`date +%Y%m%d`
    mytmpfile=${TMPDIR:-/tmp}/$mydt.$PPID
    perm1=`stat --format=%%a %{_sysconfdir}/%{pkgname}/admin-serv 2> /dev/null`
    if [ -z "$perm1" ] ; then
        perm1=0
    fi
    own1=`stat --format=%%U:%%G %{_sysconfdir}/%{pkgname}/admin-serv 2> /dev/null`
    if [ -z "$own1" ] ; then
        own1=0
    fi
    perm2=`stat --format=%%a %{_sysconfdir}/%{pkgname}/admin-serv/console.conf 2> /dev/null`
    if [ -z "$perm2" ] ; then
        perm2=0
    fi
    own2=`stat --format=%%U:%%G %{_sysconfdir}/%{pkgname}/admin-serv/console.conf 2> /dev/null`
    if [ -z "$own2" ] ; then
        own2=0
    fi
    echo $perm1 $own1 $perm2 $own2 > $mytmpfile
fi

%post
/sbin/chkconfig --add %{pkgname}-admin
/sbin/ldconfig
# if installing for the first time, make sure the config
# directory and file have the correct permissions
# the setup script is used to "fix" these
if [ "$1" -gt 1 ]; then
    set -x
    mydt=`date +%Y%m%d`
    mytmpfile=${TMPDIR:-/tmp}/$mydt.$PPID
    if [ ! -f $mytmpfile ] ; then
        echo Error: upgrade temp file $mytmpfile not found
        exit 1
    fi
    cat $mytmpfile | while read perm1 own1 perm2 own2 ; do
        chmod $perm1 %{_sysconfdir}/%{pkgname}/admin-serv
        chown $own1 %{_sysconfdir}/%{pkgname}/admin-serv
        chmod $perm2 %{_sysconfdir}/%{pkgname}/admin-serv/console.conf
        chown $own2 %{_sysconfdir}/%{pkgname}/admin-serv/console.conf
    done
    rm -f $mytmpfile
fi

%preun
if [ $1 = 0 ]; then
        /sbin/service %{pkgname}-admin stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del %{pkgname}-admin
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE
%dir %{_sysconfdir}/%{pkgname}/admin-serv
%config(noreplace)%{_sysconfdir}/%{pkgname}/admin-serv/*.conf
%{_datadir}/%{pkgname}
%{_initrddir}/%{pkgname}-admin
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}-admin
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{pkgname}
%{_mandir}/man8/*

%changelog
* Fri Jan 28 2011 Nathan Kinder <nkinder@redhat.com> - 8.2.1-1
- Resolves: bug 672468
- Description: Avoid empty path elements in library search paths
- pulled from git tag Directory_Server_8_2_Errata_Candidate_10610_20110128

* Tue Jun  8 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-4
- Resolves: 601865
- Description: added missing manpages
- pulled from git tag Directory_Server_8_2_Candidate_20100608

* Wed May 26 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-3
- 8.2 release candidate
- pulled from git tag Directory_Server_8_2_Candidate_20100526

* Fri Feb 12 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-2
- Added specific version for adminutil-devel build requirement

* Thu Feb 11 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-1
- change license to GPLv2 + ASL 2.0
- changed files that were incorrectly licensed as GPLv2+ to plain GPLv2

* Wed Apr  8 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-9
- Resolves: bug 494980
- Description: setup-ds-admin.pl -u and silent setup complain about ServerIpAddress
- CVS tag Directory_Server_8_1_Candidate_20090408

* Fri Apr  3 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-8
- Resolves: bug 493989
- Description: Admin Server: valgrind invalid read in security.c when installing CRL
- CVS tag Directory_Server_8_1_Candidate_20090403

* Tue Mar 17 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-7
- Updated to latest sources.
- CVS tag FedoraDirSrvAdmin_1_1_7 and FedoraDirSrvAdmin_1_1_7_20090317

* Mon Mar  2 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-6
- Resolves: bug 488098
- Description:  RHEL4 DS 8.1 migration fails with permissions problem - admin server configuration files
- Needed to use %m instead of %M
- Pick up latest fixes
- CVS tag FedoraDirSrvAdmin_1_1_7 and FedoraDirSrvAdmin_1_1_7_20090302

* Fri Feb 27 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-5
- added man pages for setup, migration, remove commands
- better error handling for command line utilities
- fixed remove from console
- added remove-ds-admin.pl
- CVS tag FedoraDirSrvAdmin_1_1_7 and FedoraDirSrvAdmin_1_1_7_20090227

* Wed Feb 25 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-4
- new setup/upgrade/migration code - make sure console is updated
- correctly after migration - never delete entries when doing instance
- creation/setup/upgrade/migration

* Tue Feb 10 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-3
- fix minor valgrind issue with security CGI
- CVS tag FedoraDirSrvAdmin_1_1_7 and FedoraDirSrvAdmin_1_1_7_20090210

* Mon Feb  9 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-2
- updated source for bug fixes
- added pre and post sections in order to preserve the permissions and ownerships
- of admin-serv and console.conf upon upgrade install

* Thu Jan  8 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-1
- initial commit for 8.1.0 release

* Thu Jul 24 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-3
- Resolves: bug 431103 - CRM 1803696 Unable to register a new RHDS 8.0 to a configuration server
- the bug was reopened due to a QA failure

* Tue Jul 15 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-2
- build system tagging fixed - rebuilding

* Mon Jul 14 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-1
- Resolves: bug 431103 - CRM 1803696 Unable to register a new RHDS 8.0 to a configuration server
- Resolves: bug 452323 - RHDS80 Console - Create new instance fails (only) after admin server restart 
- Resolves: bug 442103 - RHDS8.0 "manage certificates" and ssl in console java.lang.NullPointerException
- Removed obsoleted patch files

* Fri Mar 14 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.0-6
- forgot to add the patch commands for bug 437320 bug 437301

* Thu Mar 13 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.0-5
- Resolves: bug 437320
- added admserv.conf.patch
- disallow direct access to /bin/admin/admin/bin/
- Resolves: bug 437301
- added repl-monitor-cgi.pl.patch
- None of the CGI params are used anymore, except the refreshinterval,
- which is passed to int() first to strip all non numerics.  The
- repl monitor config file is now hard coded to be
- /etc/dirsrv/admin-serv/replmon.conf - this file must be present and
- configured correctly in order for the repl mon cgi to work

* Tue Dec 18 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-4
- fixes GA stopper Bug 426056: Unable to connect to admin express via SSL - firefox cipher issues?
- new RHDS 8.0.0 GA candidate

* Mon Dec 17 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-3
- fixes GA stopper bugs 425861: Instance creation through console is broken
- and 425849: migrate-ds-admin.pl spins at 100% cpu
- new GA candidate

* Tue Dec 10 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-2
- this is the GA candidate

* Tue Dec 10 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-1.16
- fix several ga blocker issues
- add dependency on dirsec-nss-tools

* Tue Nov  6 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.15
- fix several beta blocker issues

* Thu Oct 11 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.14
- make admin server work with SELinux enabled
- fix wording errors in setup

* Mon Oct  8 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.13
- added /etc/sysconfig/dirsrv-admin the file that allows you to set
- the environment used to start up the admin server (e.g. keytab, ulimit, etc.)
- the initscript and admin start script use this file now
- This version also has a fix to print the correct error message if the admin
- server cannot be contacted during setup or migration.

* Thu Sep 27 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.12
- fix a couple of migration issues, including the rpath $libdir problem
- allow ds_remove from console to remove instances

* Wed Sep 19 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.11
- one line fix to fix of 295001 - console.conf clobbered

* Tue Sep 18 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.10
- fixed migration issue bugzilla 295001 - console.conf clobbered

* Fri Sep 14 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.9
- fix several more migration problems

* Fri Sep 14 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.8
- fix migration - migration will now start servers

* Tue Aug 21 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.7
- fix with-fhs-opt configure option

* Fri Aug 17 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.6
- remove curses
- make mod_admserv link against sasl
- add the usual .m4 files to mod_admserv instead of having all of
- the component logic in configure.in

* Thu Aug 16 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.5.el4dsrv
- incorporate Noriko's migration fix

* Wed Aug 15 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.4.el4dsrv
- fix several migration related problems

* Mon Aug 13 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.3.el4dsrv
- There is no devel package, so remove unused .so files

* Mon Aug 13 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.2.el4dsrv
- forgot to tag modules

* Fri Aug 10 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1.1.el4dsrv
- use pkgname of dirsrv for filesystem path naming
- get rid of devel package
- simplify files section

* Fri Aug 10 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-0.8.el4dsrv
- updated to latest sources
- upgraded the mozldap6 version to 6.0.4

* Wed Aug  8 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-0.7.el4dsrv
- removed %{?cvsdate}; set Release to 7 to avoid the conflict

* Wed Aug  8 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-0.4.20070808
- updated the cvsdate

* Wed Aug  8 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-0.3.20070808
- updated to latest sources

* Mon Aug  6 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.2.20070806
- wrong date in changelog

* Mon Aug  6 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.1.20070806
- update to latest sources

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.2.20070802
- uploaded correct source file

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.1.20070802
- version should be 8.0.0

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.4.20070802
- There are no files in bindir anymore

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.3.20070802
- forgot to prepend build root to java dir creation

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.2.20070802
- forgot to add mod_admserv and mod_restartd to source

* Thu Aug  2 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070802
- updated to latest sources - fix build breakage
- add console jars dir under html

* Wed Jul 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070725
- Initial version based on fedora-ds-admin.spec

